@@ -61,9 +61,9 @@ class DetectController:
         raise Exception(res.text)
 
     @verify_credentials
-    def list_tags(self):
-        """ Get all tags associated to an Account """
-        res = requests.get(f'{self.account.hq}/account/tag', headers=self.account.headers)
+    def list_probes(self):
+        """ Get all probes associated to an Account """
+        res = requests.get(f'{self.account.hq}/account/probes', headers=self.account.headers)
         if res.status_code == 200:
             return res.json()
         raise Exception(res.text)
